//
// C++ Interface: scriptprg
//
// Description: 
//
//
// Author: Krippel Harald <harald@the-develop.net>, (C) 2007
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef SCRIPTPRG_H
#define SCRIPTPRG_H

/**
Basisclass for scripting implementation

	@author Krippel Harald <harald@the-develop.net>
*/

#include <QObject>

class scriptPrg: public QObject
{
Q_OBJECT
public:
    scriptPrg(QObject *parent=0);
    virtual int compile(void);
    virtual int run(void);
    virtual void update(void);
    virtual void TurnOn(void);
    virtual void TurnOff(void);
    ~scriptPrg();

public slots:
    void slot_update(const QString &);
    void slot_compile(void);
    void slot_run(void);
signals:
    void	scr_update();

protected:
  int on;
  int enable;
  int isupdate;
};

#endif
